#! /bin/bash
#
# install script für Classroommanagement MAus
#
##################################################################

pfad="/home/samba/progs/maus/"
keyname="maus-key"
vncpass="/etc/x11vnc.pass"
vncname="x11vnc.pass"
vnctext="x11vnc.text"

mdpfad="/home/samba/progs/mausdienst/"


##################################################################

if [ "$(id -u)" != "0" ]; then
   echo "###################################"
   echo "# This script must be run as root #"
   echo "###################################"
   exit 1
fi

if [ -e "$pfad"maus.cfg ]; then
   echo "######################################"
   echo "# Das Programm ist schon installiert #"
   echo "# Installation wird abgebrochen      #"
   echo "######################################"
   exit 1
fi

apt-get -y install gksu suckless-tools wakeonlan xvnc4viewer putty-tools openssl

mkdir -p $pfad
mkdir -p $mdpfad

ssh-keygen -t rsa -N '' -f "$pfad$keyname"

/usr/bin/puttygen "$pfad$keyname" -o "$pfad$keyname".ppk
/usr/bin/puttygen -l "/etc/ssh/ssh_host_rsa_key" | awk -F' ' '{print $3}' > "$pfad"host-rsa-key.fingerprint


touch /root/.ssh/authorized_keys
cat "$pfad$keyname".pub >> /root/.ssh/authorized_keys
chmod 600 /root/.ssh/authorized_keys

sed -i".old" "s/\(AllowUsers.*\)/\1 root/"  /etc/ssh/sshd_config

apg -n 1 -m 16 -M c | tr -d "\n" > "$pfad"mausdienst.pass
md5sum "$pfad"mausdienst.pass | awk -F" " '{print $1}' > "$mdpfad"mausdienst.md5

openssl genrsa -out "$mdpfad"mausdienst.key 2048
openssl req -x509 -new -nodes -subj "/C=DE/ST=BW/L=Schule/O=Mausdienst/CN=Mausdienst" -extensions v3_ca -key "$mdpfad"mausdienst.key -days 3650 -out "$mdpfad"mausdienst.cert -sha512

echo "Dateien werden zum server kopiert ..."
cp startmaus $pfad
cp maus.cfg $pfad
cp maus.ico $pfad
cp maus.desktop $pfad
cp closed.xbm $pfad
cp sperren.sh $pfad
cp freigeben.sh $pfad
cp maus.exe $pfad
cp libeay32.dll $pfad
cp ssleay32.dll $pfad
cp wol.exe $pfad
cp plink.exe $pfad
if [ -e "$vncpass" ]; then
  cp "$vncpass" "$pfad$vncname"
  chmod 640 "$pfad$vncname"
fi
touch "$pfad$vnctext"

chown -R pgmadmin:teachers $pfad
chmod 640 "$pfad$keyname"
chmod 640 "$pfad$keyname".ppk
chmod 640 "$pfad"host-rsa-key.fingerprint
chmod 640 "$pfad"mausdienst.pass
chmod 640 "$pfad$keyname".pub
chmod 640 "$pfad"maus.cfg
chmod 750 "$pfad"startmaus
chmod 750 "$pfad"maus.exe
chmod 640 "$pfad$vnctext"

cp mausdienst/mausdienst.exe $mdpfad
cp mausdienst/mausdienst.cfg $mdpfad
cp mausdienst/libeay32.dll $mdpfad
cp mausdienst/ssleay32.dll $mdpfad
cp mausdienst/winKeyLockHook.dll $mdpfad

chown -R pgmadmin:teachers $mdpfad
chmod -R 755 $mdpfad

echo "Dateien werden lokal kopiert ..."
cp maus.ico /usr/share/icons/
chmod 644 /usr/share/icons/maus.ico
cp maus.desktop /usr/share/applications/
chmod 755 /usr/share/applications/maus.desktop
mkdir -p /root/bin/
cp closed.xbm /root/bin/
cp sperren.sh /root/bin/
cp freigeben.sh /root/bin/
chmod 750 /root/bin/sperren.sh
chmod 750 /root/bin/freigeben.sh

exit 0
